@@ -160,6 +160,14 @@ class PinpointSMSVoiceV2Client(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_pinpoint_sms_voice_v2/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-sms-voice-v2.html#PinpointSMSVoiceV2.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_pinpoint_sms_voice_v2/client/#close)
+        """
+
     def create_configuration_set(
         self, *, ConfigurationSetName: str, Tags: Sequence[TagTypeDef] = ..., ClientToken: str = ...
     ) -> CreateConfigurationSetResultTypeDef:
